<?php
require __DIR__ . '/../config.php';
requireLogin();

// ID取得・検証
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$id) {
    header('Location: announcement_list.php');
    exit;
}

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title']);
    $date  = trim($_POST['publish_date']);
    $link  = trim($_POST['link']);

    if ($title === '' || $date === '') {
        $error = 'タイトルと公開日は必須です';
    } else {
        $stmt = $pdo->prepare(
            "UPDATE announcements 
             SET title = :title, publish_date = :date, link = :link 
             WHERE id = :id"
        );
        $stmt->execute([
            ':title' => $title,
            ':date'  => $date,
            ':link'  => $link,
            ':id'    => $id,
        ]);
        header('Location: announcement_list.php');
        exit;
    }
}

// 既存データ取得
$stmt = $pdo->prepare("SELECT * FROM announcements WHERE id = ?");
$stmt->execute([$id]);
$ann = $stmt->fetch(PDO::FETCH_ASSOC);
if (!$ann) {
    header('Location: announcement_list.php');
    exit;
}
?>
<!doctype html>
<html lang="ja">
<head>
  <meta charset="utf-8">
  <title>お知らせ編集</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <div class="container">
    <h1>お知らせ編集</h1>

    <?php if ($error): ?>
      <p class="error"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>

    <form action="" method="post">
      <div>
        <label>タイトル
          <input class="form-control" type="text" name="title"
                 value="<?= htmlspecialchars($_POST['title'] ?? $ann['title'], ENT_QUOTES) ?>">
        </label>
      </div>
      <div>
        <label>公開日
          <input class="form-control" type="date" name="publish_date"
                 value="<?= htmlspecialchars($_POST['publish_date'] ?? $ann['publish_date'], ENT_QUOTES) ?>">
        </label>
      </div>
      <div>
        <label>リンク先
          <!-- type を url から text に変更し、相対パスも入力可能に -->
          <input class="form-control" type="text" name="link"
                 value="<?= htmlspecialchars($_POST['link'] ?? $ann['link'], ENT_QUOTES) ?>">
        </label>
      </div>
      <button class="btn btn-primary" type="submit">更新</button>
    </form>

    <p><a href="announcement_list.php">← お知らせ一覧に戻る</a></p>
  </div>
</body>
</html>
