<?php
require __DIR__ . '/../config.php';
requireLogin();

// — POST: 一括削除 —
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (!empty($_POST['delete_ids'])) {
        $ids = array_map('intval', $_POST['delete_ids']);
        $placeholders = implode(',', array_fill(0, count($ids), '?'));
        $stmt = $pdo->prepare("DELETE FROM announcements WHERE id IN ($placeholders)");
        $stmt->execute($ids);
    }
    header('Location: announcement_list.php');
    exit;
}

// — GET: 個別削除 —
if (isset($_GET['delete_id'])) {
    $id = (int)$_GET['delete_id'];
    $stmt = $pdo->prepare("DELETE FROM announcements WHERE id = ?");
    $stmt->execute([$id]);
    header('Location: announcement_list.php');
    exit;
}

// — データ取得 —
$anns = $pdo->query("
    SELECT *
    FROM announcements
    ORDER BY publish_date DESC
")->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>お知らせ一覧</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>お知らせ一覧</h2>
    <p><a class="btn btn-primary" href="announcement_create.php">新規作成</a></p>

    <form method="post" onsubmit="return confirm('選択したお知らせを本当に削除しますか？');">
      <table class="table">
        <thead>
          <tr>
            <th><input type="checkbox" id="checkAllAnn"></th>
            <th>ID</th>
            <th>タイトル</th>
            <th>公開日</th>
            <th>リンク</th>
            <th>操作</th>
          </tr>
        </thead>
        <tbody>
          <?php foreach ($anns as $a): ?>
            <tr>
              <td>
                <input type="checkbox" name="delete_ids[]" value="<?= $a['id'] ?>">
              </td>
              <td><?= $a['id'] ?></td>
              <td><?= htmlspecialchars($a['title'], ENT_QUOTES) ?></td>
              <td><?= htmlspecialchars($a['publish_date'], ENT_QUOTES) ?></td>
              <td>
                <?php if ($a['link']): ?>
                  <?php
                    $linkUrl = $a['link'];
                    // スキーム付き (http://, https://, //) やルート始まり (/) でなければ、
                    // CMS フォルダから一つ上のルートへ相対移動
                    if (!preg_match('#^(?:[a-z][a-z0-9+.-]*:|//|/)#i', $linkUrl)) {
                        $linkUrl = '../' . ltrim($linkUrl, '/');
                    }
                  ?>
                  <a href="<?= htmlspecialchars($linkUrl, ENT_QUOTES) ?>" target="_blank">
                    リンク
                  </a>
                <?php else: ?>
                  －
                <?php endif; ?>
              </td>
              <td>
                <a class="btn btn-primary" href="announcement_edit.php?id=<?= $a['id'] ?>">
                  編集
                </a>
                <a class="btn btn-danger"
                   href="?delete_id=<?= $a['id'] ?>"
                   onclick="return confirm('ID <?= $a['id'] ?> を削除しますか？');">
                  削除
                </a>
              </td>
            </tr>
          <?php endforeach; ?>
        </tbody>
      </table>

      <button class="btn btn-danger" type="submit">一括削除</button>
    </form>
  </div>

  <script>
    // お知らせ一覧の全選択／全解除
    document.getElementById('checkAllAnn').addEventListener('change', function(){
      document.querySelectorAll('input[name="delete_ids[]"]')
              .forEach(cb => cb.checked = this.checked);
    });
  </script>
</body>
</html>
