<?php
require __DIR__ . '/../config.php';
requireLogin();

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $slug = trim($_POST['slug']);
    if ($name === '' || $slug === '') {
        $error = '名前とスラグは必須です';
    } else {
        try {
            $stmt = $pdo->prepare("INSERT INTO categories (name, slug) VALUES (?, ?)");
            $stmt->execute([$name, $slug]);
            header('Location: category_list.php');
            exit;
        } catch (PDOException $e) {
            if (strpos($e->getMessage(), 'UNIQUE') !== false) {
                $error = 'そのスラグは既に使われています';
            } else {
                $error = 'データベースエラーが発生しました';
            }
        }
    }
}
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>新規カテゴリー作成</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>新規カテゴリー作成</h2>

    <?php if ($error): ?>
      <p style="color:red;"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>

    <form method="post">
      <div>
        <label>名前
          <input class="form-control" name="name" required>
        </label>
      </div>

      <div style="margin-bottom: 2rem;">
        <label>スラグ
          <input class="form-control" name="slug" required>
        </label>
        <small>（URL用に英小文字・数字・ハイフン等）</small>
      </div>

      <button class="btn btn-primary" type="submit">作成</button>
    </form>

    <p><a href="category_list.php">← カテゴリー一覧に戻る</a></p>
  </div>
</body>
</html>
