<?php
require __DIR__ . '/../config.php';
requireLogin();

// ID取得・検証
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$id) {
    header('Location: content_list.php');
    exit;
}

// 該当データ取得
$stmt = $pdo->prepare("SELECT * FROM contents WHERE id = ?");
$stmt->execute([$id]);
$item = $stmt->fetch(PDO::FETCH_ASSOC);
if (!$item) {
    header('Location: content_list.php');
    exit;
}

// カテゴリー一覧
$cats = $pdo->query("SELECT * FROM categories ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title       = trim($_POST['title']);
    $body        = trim($_POST['body']);
    $category_id = $_POST['category'] ?: null;

    // 画像更新処理
    $imagePath = $item['image'];
    if (!empty($_FILES['image']['name'])) {
      $okTypes = ['image/jpeg','image/png','image/gif'];
      if (in_array($_FILES['image']['type'], $okTypes) && $_FILES['image']['error'] === UPLOAD_ERR_OK) {
        $upDir = __DIR__ . '/uploads/';
        if (!is_dir($upDir)) mkdir($upDir, 0755, true);
        $fn = time() . '_' . basename($_FILES['image']['name']);
        if (move_uploaded_file($_FILES['image']['tmp_name'], $upDir . $fn)) {
          $imagePath = 'uploads/' . $fn;
        } else {
          $error = '画像アップロードに失敗しました';
        }
      } else {
        $error = '未対応の画像形式です';
      }
    }

    if (!$error) {
      $stmt = $pdo->prepare("
        UPDATE contents
        SET title = :title,
            body  = :body,
            image = :img,
            category_id = :cat
        WHERE id = :id
      ");
      $stmt->execute([
        ':title' => $title,
        ':body'  => $body,
        ':img'   => $imagePath,
        ':cat'   => $category_id,
        ':id'    => $id
      ]);
      header('Location: content_list.php');
      exit;
    }
}
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>リスト編集 (ID <?= $item['id'] ?>)</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>リスト編集 (ID <?= $item['id'] ?>)</h2>

    <?php if ($error): ?>
      <p style="color:red;"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>

    <form method="post" enctype="multipart/form-data">
      <div>
        <label>タイトル
          <input
            class="form-control"
            name="title"
            value="<?= htmlspecialchars($item['title'], ENT_QUOTES) ?>"
            required>
        </label>
      </div>

      <div>
        <label>説明文
          <textarea
            class="form-control"
            name="body"
            rows="5"><?= htmlspecialchars($item['body'], ENT_QUOTES) ?></textarea>
        </label>
      </div>

      <div>
        <label>カテゴリー
          <select class="form-control" name="category">
            <option value="">未選択</option>
            <?php foreach($cats as $c): ?>
              <option
                value="<?= $c['id'] ?>"
                <?= $item['category_id'] == $c['id'] ? 'selected' : '' ?>>
                <?= htmlspecialchars($c['name'], ENT_QUOTES) ?>
              </option>
            <?php endforeach; ?>
          </select>
        </label>
      </div>

      <div>
        <label>現在の画像</label><br>
        <?php if ($item['image']): ?>
          <img src="<?= htmlspecialchars($item['image'], ENT_QUOTES) ?>" style="max-height:80px;">
        <?php else: ?>
          <p>画像なし</p>
        <?php endif; ?>
      </div>

      <div>
        <label>新しい画像
          <input class="form-control" type="file" name="image" accept="image/*">
        </label>
      </div>

      <button class="btn btn-primary" type="submit">更新する</button>
    </form>

    <p><a href="content_list.php">← 一覧に戻る</a></p>
  </div>
</body>
</html>
