<?php
require __DIR__ . '/../config.php';
requireLogin();

// — POST: 一括削除 —
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (!empty($_POST['delete_ids'])) {
        $ids = array_map('intval', $_POST['delete_ids']);
        $placeholders = implode(',', array_fill(0, count($ids), '?'));

        // --- 追加: 削除対象レコードの画像パスを取得してファイル削除 ---
        $stmt = $pdo->prepare("SELECT image FROM contents WHERE id IN ($placeholders)");
        $stmt->execute($ids);
        $rows = $stmt->fetchAll(PDO::FETCH_ASSOC);
        foreach ($rows as $row) {
            if (!empty($row['image'])) {
                $file = __DIR__ . '/' . $row['image'];
                if (file_exists($file)) {
                    @unlink($file);
                }
            }
        }

        // --- DBレコード削除 ---
        $stmt = $pdo->prepare("DELETE FROM contents WHERE id IN ($placeholders)");
        $stmt->execute($ids);
    }
    header('Location: content_list.php');
    exit;
}

// — GET: 個別削除 —
if (isset($_GET['delete_id'])) {
    $id = (int)$_GET['delete_id'];

    // --- 追加: 個別削除前に画像ファイルを削除 ---
    $stmt = $pdo->prepare("SELECT image FROM contents WHERE id = ?");
    $stmt->execute([$id]);
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($row && !empty($row['image'])) {
        $file = __DIR__ . '/' . $row['image'];
        if (file_exists($file)) {
            @unlink($file);
        }
    }

    // --- DBレコード削除 ---
    $stmt = $pdo->prepare("DELETE FROM contents WHERE id = ?");
    $stmt->execute([$id]);

    header('Location: content_list.php');
    exit;
}

// — カテゴリー一覧取得（絞り込み用） —
$cats = $pdo->query("SELECT * FROM categories ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

// — データ取得 —
$items = $pdo->query("
    SELECT c.*, COALESCE(cat.name,'未設定') AS category
    FROM contents AS c
    LEFT JOIN categories AS cat ON c.category_id = cat.id
    ORDER BY c.created_at DESC
")->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>コンテンツ一覧</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>コンテンツ一覧</h2>

    <!-- カテゴリー絞り込み -->
    <div style="margin-bottom: 1em;">
      <label>
        絞り込み：
        <select id="filterCategory">
          <option value="">すべて</option>
          <?php foreach ($cats as $c): ?>
            <option value="<?= htmlspecialchars($c['name'], ENT_QUOTES) ?>">
              <?= htmlspecialchars($c['name'], ENT_QUOTES) ?>
            </option>
          <?php endforeach; ?>
        </select>
      </label>
    </div>

    <p><a class="btn btn-primary" href="content_create.php">新規登録</a></p>

    <form method="post" onsubmit="return confirm('選択したコンテンツを本当に削除しますか？');">
      <table class="table">
        <thead>
          <tr>
            <th><input type="checkbox" id="checkAll"></th>
            <th>ID</th>
            <th>タイトル</th>
            <th>カテゴリ</th>
            <th>画像</th>
            <th>登録日時</th>
            <th>操作</th>
          </tr>
        </thead>
        <tbody>
          <?php foreach ($items as $r): ?>
            <tr data-category="<?= htmlspecialchars($r['category'], ENT_QUOTES) ?>">
              <td>
                <input type="checkbox" name="delete_ids[]" value="<?= $r['id'] ?>">
              </td>
              <td><?= $r['id'] ?></td>
              <td><?= htmlspecialchars($r['title'], ENT_QUOTES) ?></td>
              <td><?= htmlspecialchars($r['category'], ENT_QUOTES) ?></td>
              <td>
                <?php if ($r['image']): ?>
                  <img src="<?= htmlspecialchars($r['image'], ENT_QUOTES) ?>" style="max-height:50px;">
                <?php endif; ?>
              </td>
              <td><?= $r['created_at'] ?></td>
              <td>
                <a class="btn btn-primary" href="content_edit.php?id=<?= $r['id'] ?>">編集</a>
                <a class="btn btn-danger"
                   href="?delete_id=<?= $r['id'] ?>"
                   onclick="return confirm('ID <?= $r['id'] ?> を削除しますか？');">
                  削除
                </a>
              </td>
            </tr>
          <?php endforeach; ?>
        </tbody>
      </table>

      <button class="btn btn-danger" type="submit">一括削除</button>
    </form>
  </div>

  <script>
    // 全選択／全解除（表示中の行だけを対象）
    document.getElementById('checkAll').addEventListener('change', function(){
      var checked = this.checked;
      document.querySelectorAll('tbody tr').forEach(function(tr){
        if (tr.style.display !== 'none') {
          var cb = tr.querySelector('input[name="delete_ids[]"]');
          if (cb) cb.checked = checked;
        }
      });
    });

    // カテゴリー絞り込み
    document.getElementById('filterCategory').addEventListener('change', function() {
      var sel = this.value;
      document.querySelectorAll('tbody tr').forEach(function(tr) {
        if (!sel || tr.getAttribute('data-category') === sel) {
          tr.style.display = '';
        } else {
          // 非表示行のチェックも解除
          tr.style.display = 'none';
          var cb = tr.querySelector('input[name="delete_ids[]"]');
          if (cb) cb.checked = false;
        }
      });
      // 上部チェックボックスはリセット
      document.getElementById('checkAll').checked = false;
    });
  </script>
</body>
</html>
