<?php
require __DIR__ . '/config.php';

// act パラメータ取得（デフォルトは home）
$act = $_GET['act'] ?? 'home';

// ■— 詳細ページ機能無効化 —■
if ($act === 'item') {
    // 詳細ページ機能を使わないため、トップへリダイレクト
    header('Location: index.php');
    exit;
}

// ■— トップ or カテゴリ一覧 —■
// テンプレート選択
$templateFile = ($act === 'category' && isset($_GET['slug']))
    ? 'template_list.html'
    : 'template_index.html';
$template = file_get_contents(__DIR__ . '/' . $templateFile);

// プレースホルダー初期化
$replacements = [
    '{{CATEGORIES}}'     => '',
    '{{NEWS}}'           => '',
    '{{ANNOUNCEMENTS}}'  => '',
    '{{CATEGORY_NAME}}'  => '',
];

// 共通：カテゴリーナビ生成
$cats = $pdo->query("SELECT * FROM categories ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);
$htmlCats = '<ul class="categories">';
foreach ($cats as $c) {
    $htmlCats .= sprintf(
        '<li><a href="index.php?act=category&slug=%s">%s</a></li>',
        htmlspecialchars($c['slug'], ENT_QUOTES),
        htmlspecialchars($c['name'], ENT_QUOTES)
    );
}
$htmlCats .= '</ul>';
$replacements['{{CATEGORIES}}'] = $htmlCats;

// ホーム or カテゴリ一覧：記事取得
if ($act === 'category' && isset($_GET['slug'])) {
    // カテゴリー情報取得
    $slug = $_GET['slug'];
    $stmtCat = $pdo->prepare("SELECT id, name FROM categories WHERE slug = ?");
    $stmtCat->execute([$slug]);
    $catInfo = $stmtCat->fetch(PDO::FETCH_ASSOC);
    if (!$catInfo) {
        header('Location: index.php');
        exit;
    }
    $replacements['{{CATEGORY_NAME}}'] = htmlspecialchars($catInfo['name'], ENT_QUOTES);
    // そのカテゴリ内の全件取得
    $stmt = $pdo->prepare("
        SELECT id, title, image, body, created_at
        FROM contents
        WHERE category_id = ?
        ORDER BY created_at DESC
    ");
    $stmt->execute([$catInfo['id']]);
    $items = $stmt->fetchAll(PDO::FETCH_ASSOC);
} else {
    // トップ：最新３件取得
    $items = $pdo->query("
        SELECT id, title, image, body, created_at
        FROM contents
        ORDER BY created_at DESC
        LIMIT 3
    ")->fetchAll(PDO::FETCH_ASSOC);
}

// 一覧ブロック生成（{{NEWS}} に出力）
$htmlList = '<div class="list-grid">';
foreach ($items as $n) {
    $imgHtml = '';
    if (!empty($n['image'])) {
        $imgHtml = '<figure><img src="cms/' . htmlspecialchars($n['image'], ENT_QUOTES) . '" alt=""></figure>';
    }
    $htmlList .= '<div class="list">' . $imgHtml;
    // リンクを外してタイトルのみ表示
    $htmlList .= '<h4>' . htmlspecialchars($n['title'], ENT_QUOTES) . '</h4>';
    // 本文
    $htmlList .= '<p>' . nl2br(htmlspecialchars($n['body'], ENT_QUOTES)) . '</p>';
    $htmlList .= '</div>';
}
$htmlList .= '</div>';
$replacements['{{NEWS}}'] = $htmlList;

// 共通：お知らせ（最新5件）
$anns = $pdo->query("
    SELECT * FROM announcements
    ORDER BY publish_date DESC
    LIMIT 5
")->fetchAll(PDO::FETCH_ASSOC);
$htmlAnns = '<dl class="new">';
foreach ($anns as $a) {
    $date  = str_replace('-', '/', substr($a['publish_date'], 0, 10));
    $label = htmlspecialchars($a['title'], ENT_QUOTES);
    if (!empty($a['link'])) {
        $label = '<a href="' . htmlspecialchars($a['link'], ENT_QUOTES) . '">' . $label . '</a>';
    }
    $htmlAnns .= '<dt>' . $date . '</dt><dd>' . $label . '</dd>';
}
$htmlAnns .= '</dl>';
$replacements['{{ANNOUNCEMENTS}}'] = $htmlAnns;

// ■— 出力 —■
echo strtr($template, $replacements);
